(* $Id: godi_ptool.mli 963 2012-05-24 20:46:32Z gerd $
 * ----------------------------------------------------------------------
 * Copyright 2005 by Gerd Stolpmann.
 *
 * This file is part of godi-tools.
 *
 * godi-tools is free software; you can redistribute it and/or modify it
 * under the conditions in the file LICENSE.
 *
 * godi-tools is distributed WITHOUT ANY WARRANTY, as detailed in the
 * file LICENSE.
 *)

(** Packing tool, especially handles dispersed packages *)

open Godi_types
open Godi_plist
open Godi_versions
open Godi_exec

val inst_plist_dispersion : inst_plist_element list -> dispersion
  (** Creates a dispersion from an inst PLIST (which should already be
    * normalized)
    *)

val user_plist_dispersion : ?root:Godi_file.filename -> 
                            user_plist_element list -> dispersion
  (** Takes the user PLIST file, and creates a [package_source] from that
    * containing all files the PLIST file describes. The [root]
    * must point to the root directory where the files actually
    * exist. If not passed, [root] defaults to LOCALBASE.
   *)

val stage_dispersion : Godi_file.filename -> dispersion
  (** Creates a [package_source] containing all files of a given 
    * directory.
   *)


val fixup_symlinks : console -> dispersion -> unit
  (** Fixes up symlinks that point to files of the same package. It is
    * ensured that the symlinks are relative.
   *)


val create_dispersed_package : 
      name:string ->
      version:string ->
      pkgrevision:int ->
      comment:string ->
      src_fingerprint:string option ->
      description:string ->
      godi_maintainer:string ->
      dependencies:dependency list ->
      build_dependencies:dependency list ->
      conflicts:dependency list ->
      install_message:string ->
      build_version:string ->
      build_info:string ->
      preserve:bool ->
      requirements_script:string option ->
      install_script:string option ->
      deinstall_script:string option ->
      dispersion ->
      console ->
        package
 (** Creates a dispersed package from [dispersion] and the passed meta
   * data. It is required that the [dependencies] are fulfilled by installed
   * packages. In the package the actually needed predecessor packages
   * are stored (with exact version numbers), including the indirect
   * predecessors.
  *)

val dispersed_of_installed_package : console -> package -> package
  (** Creates a dispersed package from an installed package. Effectively,
    * a new temporary directory with meta data is made, and the meta
    * data are copied into it. The package files remain at their
    * location and are _not_ copied.
   *)

val binary_of_dispersed_package : 
      console ->
      Godi_file.filename -> 
      package -> package
  (** Creates a binary package from a dispersed package *)

