(* $Id: wtool_types.mli 1167 2012-12-28 22:13:41Z gerd $ *)

type 'a result =
  [ `Ok of 'a
  | `Timeout
  | `Error of string
  ]


class type wtool_handler =
object
  method base_url : string

  method list : string -> string list result
    (* List the files at this path *)

  method get : Godi_file.tmpdir -> string list -> Godi_file.filename result list
    (* [get tdir paths]: Retrieve [paths] and return the
       results in the same order as [paths]. The files are
       stored in [tdir].
     *)

  method put : Godi_file.filename -> string -> unit result
    (* [put file path]: Uploads [file] to [path] *)


  method api : (string * string) list -> int result
    (* [api params]. The result contains the exit code *)
end


class type wtool_factory =
object
  method configure_timeout : float -> unit

  method configure_user : string -> unit

  method configure_store_passwords : bool -> unit

  method configure_localbase : string -> unit

  method open_location : string -> wtool_handler
    (* [open_location base_url] *)

  method url_help : string list
    (* For help texts: which URL schemes are supported *)

  method have_auth : bool
    (* Whether authentication is supported *)
end
